EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerBlobs_RecordChunkUpload',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Initiates a multipart blob upload.'
GO

IF OBJECT_ID('[DockerBlobs_RecordChunkUpload]') IS NOT NULL DROP PROCEDURE [DockerBlobs_RecordChunkUpload]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerBlobs_RecordChunkUpload]
(
	@Feed_Id INT,
	@Upload_Id VARCHAR(50),
	@BytesReceived_Count BIGINT,
	@AdditionalData_Bytes VARBINARY(MAX),
	@HashState_Bytes VARBINARY(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	UPDATE [DockerBlobUploads]
	   SET [BytesReceived_Count] = @BytesReceived_Count,
	       [LatestChunkReceived_Date] = GETUTCDATE(),
		   [AdditionalData_Bytes] = @AdditionalData_Bytes,
		   [HashState_Bytes] = @HashState_Bytes
	 WHERE ([Feed_Id] = @Feed_Id OR ([Feed_Id] IS NULL AND @Feed_Id IS NULL))
	   AND [Upload_Id] = @Upload_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerBlobs_RecordChunkUpload] TO [ProGetUser_Role]
GO