EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CreateLogScope',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Scope_Sequence',
    /* Description_Text        */ 'Creates a log scope.'
GO

IF OBJECT_ID('[Executions_CreateLogScope]') IS NOT NULL DROP PROCEDURE [Executions_CreateLogScope]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CreateLogScope]
(
	@Execution_Id INT,
	@Scope_Name VARBINARY(MAX),
	@Parent_Scope_Sequence INT,
	@Start_Date DATETIME,
	@Scope_Sequence INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	SET @Scope_Sequence = COALESCE((SELECT MAX([Scope_Sequence])
	                                  FROM [ScopedExecutionLogs]
	                                  WITH (UPDLOCK)
	                                 WHERE [Execution_Id] = @Execution_Id), 0) + 1

	INSERT INTO [ScopedExecutionLogs]
	(
		[Execution_Id],
		[Scope_Sequence],
		[Scope_Name],
		[Parent_Scope_Sequence],
		[Start_Date]
	)
	VALUES
	(
		@Execution_Id,
		@Scope_Sequence,
		COALESCE(@Scope_Name, 0x),
		@Parent_Scope_Sequence,
		@Start_Date
	)

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Executions_CreateLogScope] TO [ProGetUser_Role]
