EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'RpmPackages_CreateOrUpdatePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Local_FileName_Text',
    /* Description_Text        */ 'Creates a new RPM package or updates an existing one.'
GO

IF OBJECT_ID('[RpmPackages_CreateOrUpdatePackage]') IS NOT NULL DROP PROCEDURE [RpmPackages_CreateOrUpdatePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RpmPackages_CreateOrUpdatePackage]
(
	@Feed_Id INT,
	@Architecture_Name VARCHAR(50),
	@Package_Name VARCHAR(200),
	@FullVersion_Text VARCHAR(200),
	@UniqueVersion_Text VARCHAR(200),
	@Summary_Text VARCHAR(MAX),
	@Package_Size BIGINT,
	@Published_Date DATETIME,
	@SHA1_Bytes BINARY(20),
	@SHA256_Bytes BINARY(32),
	@Metadata_Bytes VARBINARY(MAX),
	@Local_FileName_Text VARCHAR(200) = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

		DECLARE @RpmPackage_Id INT
		SET @RpmPackage_Id = (SELECT [RpmPackage_Id] FROM [RpmPackages] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [Architecture_Name] = @Architecture_Name AND [Package_Name] = @Package_Name)

		IF @RpmPackage_Id IS NULL
		BEGIN

			INSERT INTO [RpmPackages]
			(
				[Feed_Id],
				[Architecture_Name],
				[Package_Name]
			)
			VALUES
			(
				@Feed_Id,
				@Architecture_Name,
				@Package_Name
			)

			SET @RpmPackage_Id = SCOPE_IDENTITY()

		END

		DECLARE @RpmPackageVersion_Id INT

		SELECT @Local_FileName_Text = COALESCE([Local_FileName_Text], @Local_FileName_Text),
		       @RpmPackageVersion_Id = [RpmPackageVersion_Id]
		  FROM [RpmPackageVersions]
		 WHERE [RpmPackage_Id] = @RpmPackage_Id
		   AND [UniqueVersion_Text] = @UniqueVersion_Text

		IF @RpmPackageVersion_Id IS NOT NULL
		BEGIN

			UPDATE [RpmPackageVersions]
			   SET [Metadata_Bytes] = COALESCE(@Metadata_Bytes, [Metadata_Bytes]),
			       [Published_Date] = COALESCE(@Published_Date, [Published_Date]),
				   [SHA1_Bytes] = COALESCE(@SHA1_Bytes, [SHA1_Bytes]),
				   [SHA256_Bytes] = COALESCE(@SHA256_Bytes, [SHA256_Bytes]),
				   [Package_Size] = COALESCE(@Package_Size, [Package_Size])
			 WHERE [RpmPackageVersion_Id] = @RpmPackageVersion_Id

			IF COALESCE(dbo.Session_GetUserName(), 'UNKNOWN') NOT IN ('SYSTEM', 'UNKNOWN')
   				EXEC [Events_RaiseEvent] 'PKGMDF', @Feed_Id, 'Package_Id', @Package_Name, 'Package_Version', @FullVersion_Text

		END
		ELSE
		BEGIN

			DECLARE @Actual_FileName VARCHAR(200) = @Local_FileName_Text
			DECLARE @Name_Index INT = 1

			WHILE EXISTS(SELECT * FROM [RpmPackages_FileNames] WHERE [Feed_Id] = @Feed_Id AND [Local_FileName_Text] = @Actual_FileName)
			BEGIN
				SET @Actual_FileName = STUFF(@Local_FileName_Text, LEN(@Local_FileName_Text) - 4, 0, '_' + CAST(@Name_Index AS VARCHAR(20)))
				SET @Name_Index = @Name_Index + 1
			END

			INSERT INTO [RpmPackageVersions]
			(
				[RpmPackage_Id],
				[UniqueVersion_Text],
				[FullVersion_Text],
				[Summary_Text],
				[Download_Count],
				[Package_Size],
				[Published_Date],
				[SHA1_Bytes],
				[SHA256_Bytes],
				[Metadata_Bytes],
				[Local_FileName_Text]
			)
			VALUES
			(
				@RpmPackage_Id,
				@UniqueVersion_Text,
				@FullVersion_Text,
				@Summary_Text,
				0,
				@Package_Size,
				@Published_Date,
				@SHA1_Bytes,
				@SHA256_Bytes,
				@Metadata_Bytes,
				@Actual_FileName
			)

			SET @Local_FileName_Text = @Actual_FileName

			EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Id', @Package_Name, 'Package_Version', @FullVersion_Text

		END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [RpmPackages_CreateOrUpdatePackage] TO [ProGetUser_Role]
GO